@@ -1,5 +1,7 @@
 import code
-if __name__ == '__main__':
+def exec():
     code.main()
+if __name__ == '__main__':
+    exec()
 # Main function
 # format_and_save()
